@@ -221,6 +221,7 @@ class FlowsSplit(Enum):
     Sellers = "seller"  #:
     VesselTypeOil = "vessel type oil"
     VesselTypeCpp = "vessel type cpp"
+    CrudeQuality = "crude quality"
 
 
 class FlowsPeriod(Enum):
@@ -421,6 +422,7 @@ class FleetMetricsSplit(Enum):
     CurrentSubregions = "current subregions"  #:
     CurrentSeas = "current seas"  #:
     FloatingDays = "floating days"  #:
+    CrudeQuality = "crude quality"  #:
 
 
 class FleetMetricsVesselsAlgo(Enum):
@@ -583,3 +585,10 @@ class InventoriesDronePeriod(Enum):
     MidWeeks = "midweeks"  #:
     EiaWeeks = "eia"  #:
     Days = "days"  #:
+
+
+class DiversionsVesselState(Enum):
+    """"""
+
+    Ballast = "Ballast"  #:
+    Loaded = "Loaded"  #:
