@@ -45,6 +45,7 @@ class CongestionVessels(KplerClient):
         waiting_duration_max: Optional[int] = None,
         with_freight_view: bool = False,
         period: Optional[Enum] = None,
+        vessels: Optional[List[str]] = None,
     ):
 
         """
@@ -65,6 +66,7 @@ class CongestionVessels(KplerClient):
             waiting_duration_max: Optional[int] Maximum waiting duration of vessel. Default to 1000000 days if not specified.
             with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
             period: Optional[Enum] ``CongestionVesselsPeriod``
+            vessels: Optional[List[str]] Names or IMOs of the vessels
 
         Examples:
             >>> from datetime import date
@@ -104,5 +106,6 @@ class CongestionVessels(KplerClient):
             "waitingDurationMax": waiting_duration_max,
             "withFreightView": process_bool_parameter(with_freight_view),
             "period": process_enum_parameter(period),
+            "vessels": process_list_parameter(vessels),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
