@@ -41,6 +41,7 @@ class Inventories(KplerClient):
         add_commodities_on_water: Optional[bool] = None,
         floating_storage_duration_min: Optional[str] = None,
         floating_storage_duration_max: Optional[str] = None,
+        without_eia_adjustment: Optional[bool] = None,
     ):
         """
         Args:
@@ -56,6 +57,7 @@ class Inventories(KplerClient):
             add_commodities_on_water: Optional[bool] Provides total volume of inventories including offshore and offshore. Default to false if not specified.
             floating_storage_duration_min: Optional[str] Minimum floating days [7-10-12-15-20-30-90]
             floating_storage_duration_max: Optional[str] Maximum floating days [10-12-15-20-30-90-Inf]
+            without_eia_adjustment:  Optional[bool] No use of EIA data for enhancing inventories volumes (default: False)
 
         Examples:
             >>> from datetime import date
@@ -94,5 +96,6 @@ class Inventories(KplerClient):
             "addCommoditiesOnWater": process_bool_parameter(add_commodities_on_water),
             "floatingStorageDurationMin": floating_storage_duration_min,
             "floatingStorageDurationMax": floating_storage_duration_max,
+            "withoutEiaAdjustment": process_bool_parameter(without_eia_adjustment),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
